@@ -5,6 +5,7 @@ import warnings
 from urllib.parse import urljoin
 
 import flattentool
+import google.auth
 import gspread
 import requests
 import sql
@@ -18,10 +19,10 @@ except ImportError:
 
     files = Mock()
     files.download.return_value = None
+
 from gspread_dataframe import set_with_dataframe
 from IPython import get_ipython
 from IPython.display import HTML
-from libcoveocds.config import LibCoveOCDSConfig
 from notebook import notebookapp
 from oauth2client.client import GoogleCredentials
 from pydrive2.auth import GoogleAuth
@@ -66,7 +67,8 @@ def authenticate_gspread():
     :rtype: gspread.Client
     """
     auth.authenticate_user()
-    return gspread.authorize(GoogleCredentials.get_application_default())
+    credentials, _ = google.auth.default()
+    return gspread.authorize(credentials)
 
 
 def authenticate_pydrive():
@@ -114,8 +116,8 @@ def list_source_ids(pattern=''):
 
     pattern = f'%{pattern}%'
 
-    # This inspects locals to find pattern
-    return get_ipython().magic(f'sql {sql}')
+    # This inspects locals to find `pattern`.
+    return get_ipython().run_line_magic('sql', sql)
 
 
 def list_collections(source_id=None):
@@ -133,8 +135,8 @@ def list_collections(source_id=None):
         sql += " WHERE source_id = :source_id"
     sql += " ORDER BY id DESC"
 
-    # This inspects locals to find source_id
-    return get_ipython().magic(f'sql {sql}')
+    # This inspects locals to find `source_id`.
+    return get_ipython().run_line_magic('sql', sql)
 
 
 def set_search_path(schema_name):
@@ -145,7 +147,7 @@ def set_search_path(schema_name):
     :param str schema_name: a schema name
     """
     try:
-        get_ipython().magic(f'sql SET search_path = {schema_name}, public')
+        get_ipython().run_line_magic('sql', f'SET search_path = {schema_name}, public')
     # https://github.com/catherinedevlin/ipython-sql/issues/191
     except ResourceClosedError:
         pass
@@ -187,18 +189,17 @@ def save_dataframe_to_spreadsheet(dataframe, name):
     """
     write_data_as_json(dataframe['release_package'][0], 'release_package.json')
 
-    config = LibCoveOCDSConfig().config
     with warnings.catch_warnings():
         warnings.filterwarnings('ignore')  # flattentool uses UserWarning, so we can't set a specific category
 
         flattentool.flatten(
             'release_package.json',
-            main_sheet_name=config['root_list_path'],
-            root_list_path=config['root_list_path'],
-            root_id=config['root_id'],
-            schema=config['schema_version_choices']['1.1'][1] + 'release-schema.json',
-            disable_local_refs=config['flatten_tool']['disable_local_refs'],
-            remove_empty_schema_columns=config['flatten_tool']['remove_empty_schema_columns'],
+            main_sheet_name='releases',  # root_list_path
+            root_list_path='releases',  # root_list_path
+            root_id='ocid',  # root_id
+            schema='https://standard.open-contracting.org/1.1/en/release-schema.json',  # schema_version_choices
+            disable_local_refs=True,  # flatten_tool.disable_local_refs
+            remove_empty_schema_columns=True,  # flatten_tool.remove_empty_schema_columns
             root_is_list=False,
             output_format='xlsx',
         )
@@ -240,18 +241,18 @@ def get_ipython_sql_resultset_from_query(sql):
     :rtype: sql.run.ResultSet
     """
     ipython = get_ipython()
-    autopandas = ipython.magic('config SqlMagic.autopandas')
+    autopandas = ipython.run_line_magic('config', 'SqlMagic.autopandas')
     # Disable autopandas, so we know that the sql magic call will always return
     # a ResultSet (rather than a pandas DataFrame). Since the DataFrame would
     # be created from the ResultSet, it would be less efficient.
     if autopandas:
-        ipython.magic('config SqlMagic.autopandas=False')
+        ipython.run_line_magic('config', 'SqlMagic.autopandas = False')
     # Use ipython.run_line_magic instead of ipython.magic here
     # to get variables from the scope of the ipython cell,
     # instead of the scope in this function.
     results = ipython.run_line_magic('sql', sql)
     if autopandas:
-        ipython.magic('config SqlMagic.autopandas=True')
+        ipython.run_line_magic('config', 'SqlMagic.autopandas = True')
     return results
 
 
@@ -300,16 +301,16 @@ def download_package_from_ocid(collection_id, ocid, package_type):
     """
 
     ipython = get_ipython()
-    autopandas = ipython.magic('config SqlMagic.autopandas')
+    autopandas = ipython.run_line_magic('config', 'SqlMagic.autopandas')
     # Disable autopandas, so we know that the sql magic call will always return
     # a ResultSet (rather than a pandas DataFrame). Since the DataFrame would
     # be created from the ResultSet, it would be less efficient.
     if autopandas:
-        ipython.magic('config SqlMagic.autopandas=False')
-    # This inspects locals to find ocid and collection_id
-    results = ipython.magic(f'sql {sql}')
+        ipython.run_line_magic('config', 'SqlMagic.autopandas = False')
+    # This inspects locals to find `ocid` and `collection_id`.
+    results = ipython.run_line_magic('sql', sql)
     if autopandas:
-        ipython.magic('config SqlMagic.autopandas=True')
+        ipython.run_line_magic('config', 'SqlMagic.autopandas = True')
 
     data = [row[0] for row in results]
 
